@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: clamav-update.pl,v 1.5 2006/11/12 12:58:14 okamura Exp $
+# $Id: clamav-update.pl,v 1.5 2006/12/02 09:52:49 okamura Exp $
 
 =head1 NAME
 
@@ -163,7 +163,7 @@ sub PrepareLogging {
 
 		*Log = *_Syslog;
 		openlog $Setting->{logging}->{openlog}->{ident},
-			$Setting->{logging}->{openlog}->{logopt},
+			join(',', @{$Setting->{logging}->{openlog}->{logopt}}),
 			$Setting->{logging}->{openlog}->{facility};
 		$SyslogOpened = 1;
 	}
@@ -207,7 +207,7 @@ sub Version {
 
 	unless ($version =~ m/$spec{regexp}/) {
 		Log 'debug', 'regexp: %s', $spec{regexp};
-		Log 'alert', 'unexpected respons: %s', $version;
+		Log 'alert', 'unexpected response: %s', $version;
 		return '';
 	}
 
@@ -218,7 +218,7 @@ sub LatestVersion {
 	my	$version = Version(%{$Setting->{version}->{latest}});
 
 	if ($version) {
-		Log 'info', 'latest ClamAV version is %s', $version; 
+		Log 'info', 'latest version is %s', $version; 
 	}
 	return $version;
 }
@@ -228,7 +228,7 @@ sub CurrentVersion {
 	my	$version = Version(%{$Setting->{version}->{current}});
 
 	if ($version) {
-		Log 'info', 'current ClamAV version is %s', $version; 
+		Log 'info', 'current version is %s', $version; 
 	}
 	return $version;
 }
@@ -263,10 +263,16 @@ sub Download {
 	my	($version) = @_;
 	my	$fname = sprintf $Setting->{download}->{name}.'%s',
 		$version, $Setting->{download}->{ext};
-	my	@command = (
+	my	$src = $Setting->{download}->{src};
+	my	@command;
+
+	if (ref($src) eq 'CODE') {
+		$src = &{$src}($version);
+	}
+	@command = (
 		'curl', '--silent', '-o',
 		sprintf('%s/%s', $Setting->{download}->{dst}, $fname),
-		sprintf('%s/%s', $Setting->{download}->{src}, $fname)
+		sprintf('%s/%s', $src, $fname)
 	);
 
 	return DoCommand(@command);
@@ -315,11 +321,31 @@ sub Clean {
 	}
 }
 
+sub CheckSecurity {
+	my	$ok = 1;
+
+	if ($> != 0) {
+		Log 'alert', 'effective user is not root: %d', $>;
+		$ok = 0;
+	}
+
+	if (-f $0) {
+		my	@st = stat $0;
+
+		if ($st[2] & 04000) {
+			Log 'alert', 'suid bit is added to this script. This is a big security hole.';
+			$ok = 0;
+		}
+	}
+
+	return $ok; 
+}
+
 
 #-------------------------------------------------------------------------------
 # グローバル変数初期値
 #-------------------------------------------------------------------------------
-$Version = 'clamav-update.pl v1.0.1';
+$Version = 'clamav-update.pl v1.1.1';
 
 $ConfigFile = "/usr/local/clamXav/etc/clamav-update.conf";
 
@@ -339,7 +365,7 @@ $Setting = {
 		setlogsock	=> \*STDERR,
 		openlog	=> {
 			ident		=> 'clamav-update',
-			logopt		=> [qw(cons)],
+			logopt		=> [qw()],
 			facility	=> 'local6',
 		},
 		setlogmask	=> 'warning',
@@ -378,12 +404,7 @@ $Setting = {
 		[qw(chown -R clamav:clamav /usr/local/clamXav/share/clamav)],
 		[qw(chmod -R ug+w /usr/local/clamXav/share/clamav)],
 	],
-	daemon	=> [
-#		[qw(chown root /usr/local/clamXav/bin/freshclam)],
-#		[qw(chmod u-s /usr/local/clamXav/bin/freshclam)],
-#		[qw(/Library/StartupItems/FreshClamDaemon/FreshClamDaemon restart)],
-#		[qw(/Library/StartupItems/ClamAntiVirusDaemon/ClamAntiVirusDaemon restart)],
-	],
+	daemon	=> [],
 	doClean	=> {
 		archive	=> 1,
 		objects	=> 0,
@@ -451,8 +472,7 @@ EOF
 #-------------------------------------------------------------------------------
 # 初期化
 Prepare();
-if ($> != 0) {
-	Log 'alert', 'effective user is not root: %d', $>;
+unless (CheckSecurity()) {
 	exit $ErrorCode{prepare};
 }
 
@@ -538,12 +558,16 @@ END {
 
 =over 4
 
-=item 1.0.1
+=item v1.1
+
+ * function reference support for $Setting->{download}->{src}.
+
+=item v1.0.1
 
  * Improve output contents of log.
  * Fix miss spelling in clamav-update.conf.
 
-=item 1.0
+=item v1.0
 
 Initial version.
 
